pilas.actores.martian.Disparar

Package pilas :: Package actores :: Module martian :: Class Disparar |
[hide private]
[frames] | no frames]

# Class Disparar

source code

                        object --+
                                 |
    comportamientos.Comportamiento --+
                                     |
                                    Disparar

Representa al actor disparando un proyectil.

Instance Methods | [hide private]
__init__(self, receptor) x.__init__(...) initializes x; see help(type(x)) for signature | source code
actualizar(self) Actualiza el comportamiento en un instante dado. | source code
avanzar_animacion(self) | source code
Inherited from `comportamientos.Comportamiento`: `iniciar`, `terminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### actualizar(self) | source code
Actualiza el comportamiento en un instante dado. Si este metodo retorna True entonces el actor dejará de ejecutar este comportamiento. Overrides: comportamientos.Comportamiento.actualizar (inherited documentation)